@@ -14,12 +14,14 @@ TestAppI18N->config(
     name => 'TestApp-I18N',
     counter => 0,
     'Plugin::Cache' => {
-        disable_index => 0,
         backend => { 
             class => 'Cache::FileCache',
             cache_root => $cache_root,
         },
     },
+    'Plugin::PageCache' => {
+        disable_index => 0,
+    },  
 );
 
 TestAppI18N->setup( qw/Cache I18N PageCache/ );
